@@ -50,7 +50,7 @@ class KSCREEN_EXPORT Edid: public QObject
 
   public:
     explicit Edid();
-    explicit Edid(const QByteArray &data, QObject *parent = 0);
+    explicit Edid(const QByteArray &data, QObject *parent = nullptr);
     virtual ~Edid();
 
     Edid* clone() const;
